@@ -116,6 +116,7 @@ pub struct ThumbNail {
     pub image_url: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub link: Option<Link>,
+    #[serde(skip_serializing_if = "is_false", default)]
     pub fixed_ratio: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub width: Option<i32>,
@@ -123,6 +124,10 @@ pub struct ThumbNail {
     pub height: Option<i32>,
 }
 
+fn is_false(b: &bool) -> bool {
+    *b == false
+}
+
 impl ThumbNail {
     pub fn new(url: String) -> Self {
         ThumbNail {
@@ -164,7 +169,7 @@ impl ThumbNail {
 /***** Main *****/
 #[derive(Serialize, Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
-/// 현재 ListCard, BasicCard, SimpleText, Carousel (Basic/CommerceCard) 지원
+/// 현재 ListCard, BasicCard, SimpleText, SimpleImage, Carousel (Basic/CommerceCard) 지원
 ///
 /// # Examples
 ///
@@ -212,7 +217,10 @@ impl Template {
 pub enum Types {
     List(ListCard),
     Basic(BasicCard),
-    Simple(SimpleText),
+    Commerce(CommerceCard),
+    Item(ItemCard),
+    SimpleTxt(SimpleText),
+    SimpleImg(SimpleImage),
     Carousel(Carousel),
 }
 
@@ -260,7 +268,7 @@ impl Outputs {
 ///         "http://k.kakaocdn.net/dn/APR96/btqqH7zLanY/kD5mIPX7TdD2NAxgP29cC0/1x1.jpg"
 ///     ));
 ///
-///     carousel.add_card(Card::Basic(basic_card));
+///     carousel.add_card(basic_card.build_card());
 /// }
 ///
 /// result.add_output(carousel.build());
@@ -296,6 +304,17 @@ impl Carousel {
 
     pub fn add_card(&mut self, card: Card) {
         self.carousel.items.push(card);
+        // match &mut card {
+        //     Card::Basic(basic) => {
+        //         self.carousel.items.push(basic.content);
+        //     }
+        //     Card::Commerce(com) => {
+        //         self.carousel.items.push(com.content);
+        //     }
+        //     Card::Item(item) => {
+        //         self.carousel.items.push(item.content);
+        //     }
+        // }
     }
 
     pub fn build(self) -> Types {
@@ -470,7 +489,7 @@ impl SimpleText {
     }
 
     pub fn build(self) -> Types {
-        Types::Simple(self)
+        Types::SimpleTxt(self)
     }
 
     pub fn html(&self) -> String {
@@ -478,4 +497,68 @@ impl SimpleText {
     }
 }
 
+#[derive(Serialize, Deserialize, Debug)]
+#[serde(rename_all = "camelCase")]
+#[serde(deny_unknown_fields)]
+/// [SimpleImage](https://i.kakao.com/docs/skill-response-format#simpleimage): imageUrl, altText
+///
+/// # Examples
+///
+/// Basic usage:
+///
+/// ```
+/// let mut result = Template::new();
+/// result.add_qr(QuickReply::new(
+///     "빠른 응답".to_string(),
+///     "빠른 응답 ㅋㅋ".to_string(),
+/// ));
+///
+/// let simple_img = SimpleImage::new(
+///     format!("http://k.kakaocdn.net/dn/83BvP/bl20duRC1Q1/lj3JUcmrzC53YIjNDkqbWK/i_6piz1p.jpg"),
+///     format!("보물상자입니다"));
+///
+/// result.add_output(simple_img.build());
+///
+/// ```
+pub struct SimpleImage {
+    simple_image: SimpleImageContent,
+}
+
+#[derive(Serialize, Deserialize, Debug)]
+#[serde(rename_all = "camelCase")]
+#[serde(deny_unknown_fields)]
+pub struct SimpleImageContent {
+    image_url: String,
+    alt_text: String,
+}
+
+impl SimpleImage {
+    pub fn new(_url: String, _text: String) -> Self {
+        SimpleImage {
+            simple_image: SimpleImageContent {
+                image_url: _url,
+                alt_text: _text,
+            },
+        }
+    }
+
+    pub fn set_image(mut self, _link: String) -> Self {
+        self.simple_image.image_url = _link;
+        self
+    }
+
+    pub fn set_text(mut self, _text: String) -> Self {
+        self.simple_image.alt_text = _text;
+        self
+    }
+
+    pub fn build(self) -> Types {
+        Types::SimpleImg(self)
+    }
+
+    pub fn html(&self) -> String {
+        format!("{}", self.simple_image.image_url)
+    }
+}
+
 /***** Response *****/
